------------------------------
--      Are you local?      --
------------------------------

local myname = "CThun Assist"
local L = AceLibrary("AceLocale-2.2"):new("BigWigs"..myname)
local boss = AceLibrary("Babble-Boss-2.2")["Eye of C'Thun"]
local cthun = AceLibrary("Babble-Boss-2.2")["C'Thun"]
local tablet = AceLibrary("Tablet-2.0")
local paintchips = AceLibrary("PaintChips-2.0")
local stage2 = nil
local lastplayed = 0

----------------------------
--      Localization      --
----------------------------

L:RegisterTranslations("enUS", function() return {
} end )

----------------------------------
--      Module Declaration      --
----------------------------------

BigWigsCThunAssist = BigWigs:NewModule(myname)
BigWigsCThunAssist.synctoken = myname
BigWigsCThunAssist.zonename = AceLibrary("Babble-Zone-2.2")["Naxxramas"]
BigWigsCThunAssist.enabletrigger = { boss }
-- BigWigsCThunAssist.toggleoptions = { }
BigWigsCThunAssist.revision = tonumber(string.sub("$Revision: 15470 $", 12, -3))

------------------------------
--      Initialization      --
------------------------------

function BigWigsCThunAssist:OnEnable()
	if not roster then roster = AceLibrary("RosterLib-2.0") end
	roster:Enable()

	stage2 = nil
	lastplayed = 0

	self:RegisterEvent("SEEAEO_UnitDebuffLost")
	self:RegisterEvent("SEEAEO_UnitDebuffGained")
	self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH")
	self:RegisterEvent("BigWigs_RecvSync")

	self:ShowTablet()
end

function BigWigsCThunAssist:OnDisable()
	roster = nil
	stage2 = nil
	self:HideTablet()
end

------------------------------
--      Events              --
------------------------------

function BigWigsCThunAssist:CHAT_MSG_COMBAT_HOSTILE_DEATH(msg)
	if msg == string.format(UNITDIESOTHER, cthun) then
		self.core:ToggleModuleActive(self, false)
	end
end

function BigWigsCThunAssist:BigWigs_RecvSync(sync)
	if sync == "CThunStart" then
		stage2 = nil
	elseif sync == "CThunP2Start" then
		stage2 = true
	end
end

------------------------------
--      Tablet              --
------------------------------

function BigWigsCThunAssist:OnTooltipUpdate()
	if not tablet:IsRegistered("BigWigs_CThunAssist") then return end

	local headertext = stage2 and L["Stomach"] or L["Too Close"]
	local cat = tablet:AddCategory(
		"columns", 1,
		"text", headertext,
		"justify", "CENTER",
		"child_justify1", "CENTER",
	)

	local tooclose = false

	for n, u in pairs(roster.roster) do
		if u and u.name and u.class ~= "PET" then
			if stage2 then
				for a=1,16 do
					local t,c = UnitDebuff(unitid,a)
					if not t then break end
					if t == "Interface\\Icons\\Ability_Creature_Disease_02" then
						cat:AddLine("text", "|cff"..paintchips:GetHex(u.class)..u.name.."|r")
					end
				end				
			else
				if CheckInteractDistance(u.unitid, 3) then
					cat:AddLine("text", "|cff"..paintchips:GetHex(u.class)..u.name.."|r")
					tooclose = true
				end
			end
		end
	end

	local t = time()
	if tooclose and t > lastplayed + 1 then
		lastplayed = time()
		self:TriggerEvent("BigWigs_Sound", "Alarm")
	end
end

function BigWigsCThunAssist:ShowTablet()
	if not tablet:IsRegistered("BigWigs_CThunAssist") then
		tablet:Register("BigWigs_CThunAssist",
			"children",
				function()
					tablet:SetTitle(L["Big Wigs CThun Assist"])
					self:OnTooltipUpdate()
				end,
			"clickable", true,
			"showTitleWhenDetached", true,
			"showHintWhenDetached", true,
			"cantAttach", true
		)
	end

	if not self:IsEventScheduled("bwcthunassistupdate") then
		self:ScheduleRepeatingEvent("bwcthunassistupdate", function() tablet:Refresh("BigWigs_CThunAssist") end, .1)
	end

	if tablet:IsAttached("BigWigs_CThunAssist") then
		tablet:Detach("BigWigs_CThunAssist")
	end
end

function BigWigsCThunAssist:HideTablet()
	if not tablet:IsRegistered("BigWigs_CThunAssist") then return end

	self:CancelScheduledEvent("bwcthunassistupdate")

	tablet:Attach("BigWigs_CThunAssist")
end

